```bash
sudo apt update && sudo apt upgrade
sudo apt install python3 python3-pip python3-venv git wget curl
```

*Note that you must set up virtual env on Ubuntu 23+ before using any Python project including CM:*
```bash
python3 -m venv cm
source cm/bin/activate
```
